==> hazelcast-all-3.1-sources.jar: com/hazelcast/util/scheduler/TimeKey.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.util.scheduler;

/**
 * @author enesakar 9/4/13
 *
 * This object is first needed for having different key objects that are created for the same key updated in different times so should be persisted consequently.
 * So using ScheduleType.FOR_EACH, all the updates will be scheduled seperately.
 */
final class TimeKey {

    private Object key;
    private long time;

    public TimeKey(Object key, long time) {
        this.key = key;
        this.time = time;
    }

    public Object getKey() {
        return key;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        TimeKey that = (TimeKey) o;

        if (time != that.time) return false;
        if (key != null ? !key.equals(that.key) : that.key != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = key != null ? key.hashCode() : 0;
        result = 31 * result + (int) (time ^ (time >>> 32));
        return result;
    }
}

==> hazelcast-all-3.2.1-sources.jar: com/hazelcast/util/scheduler/TimeKey.java <==
/*
 * Copyright (c) 2008-2013, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.util.scheduler;

/**
 * @author enesakar 9/4/13
 *
 * This object is first needed for having different key objects that are created for the same key updated in different times so should be persisted consequently.
 * So using ScheduleType.FOR_EACH, all the updates will be scheduled seperately.
 */
final class TimeKey {

    private Object key;
    private long time;

    public TimeKey(Object key, long time) {
        this.key = key;
        this.time = time;
    }

    public Object getKey() {
        return key;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        TimeKey that = (TimeKey) o;

        if (time != that.time) return false;
        if (key != null ? !key.equals(that.key) : that.key != null) return false;

        return true;
    }

    @Override
    public int hashCode() {
        int result = key != null ? key.hashCode() : 0;
        result = 31 * result + (int) (time ^ (time >>> 32));
        return result;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("TimeKey{");
        sb.append("key=").append(key);
        sb.append(",time=").append(time);
        sb.append('}');
        return sb.toString();
    }
}
